@@ -16,6 +16,7 @@ import zipfile
 from contextlib import closing
 from functools import partial
 from io import BytesIO, StringIO
+from typing import Optional
 from xml.etree import ElementTree as ET
 
 import mock
@@ -197,7 +198,7 @@ class Tests(unittest.TestCase):
 
     def test_unicodify(self):
         from check_manifest import unicodify
-        nonascii = b'\xc3\xa9.txt'.decode('UTF-8') # because Py3.2 lacks u''
+        nonascii = "\u00E9.txt"
         self.assertEqual(unicodify(nonascii), nonascii)
         self.assertEqual(
             unicodify(nonascii.encode(locale.getpreferredencoding())),
@@ -220,7 +221,7 @@ class Tests(unittest.TestCase):
     def test_get_archive_file_list_zip_nonascii(self):
         from check_manifest import get_archive_file_list
         filename = os.path.join(self.make_temp_dir(), 'archive.zip')
-        nonascii = b'\xc3\xa9.txt'.decode('UTF-8') # because Py3.2 lacks u''
+        nonascii = "\u00E9.txt"
         self.create_zip_file(filename, [nonascii])
         self.assertEqual(get_archive_file_list(filename),
                          [nonascii])
@@ -235,7 +236,7 @@ class Tests(unittest.TestCase):
     def test_get_archive_file_list_tar_nonascii(self):
         from check_manifest import get_archive_file_list
         filename = os.path.join(self.make_temp_dir(), 'archive.tar')
-        nonascii = b'\xc3\xa9.txt'.decode('UTF-8') # because Py3.2 lacks u''
+        nonascii = "\u00E9.txt"
         self.create_tar_file(filename, [nonascii])
         self.assertEqual(get_archive_file_list(filename),
                          [nonascii])
@@ -908,7 +909,8 @@ class TestZestIntegration(unittest.TestCase):
 
 class VCSHelper(object):
 
-    command = None  # override in subclasses
+    # override in subclasses
+    command = None  # type: Optional[str]
 
     def is_installed(self):
         try:
@@ -1019,8 +1021,7 @@ class VCSMixin(object):
         # "eacute".  UTF-8 or Latin-1 should work.
         from check_manifest import get_vcs_files
         self._init_vcs()
-        # A spelling of u"\xe9.txt" that works on Python 3.2 too
-        filename = b'\xc3\xa9.txt'.decode('UTF-8')
+        filename = "\u00E9.txt"
         self._create_and_add_to_vcs([filename])
         self.assertEqual(get_vcs_files(self.ui), [filename])
 
@@ -1101,6 +1102,10 @@ class TestGit(VCSMixin, unittest.TestCase):
                 'subdir/sub2/sub3/file4',
             ])
 
+    def test_get_versioned_files_with_git_submodules_with_git_index_file_set(self):
+        with mock.patch.dict(os.environ, {"GIT_INDEX_FILE": ".git/index"}):
+            self.test_get_versioned_files_with_git_submodules()
+
 
 class BzrHelper(VCSHelper):
 
@@ -1675,7 +1680,7 @@ class TestCheckManifest(unittest.TestCase):
         with open('MANIFEST.in') as f:
             self.assertEqual(
                 f.read(),
-                "#tbd\n# added by check_manifest.py\ninclude *.txt\n")
+                "#tbd\n# added by check-manifest\ninclude *.txt\n")
 
     def test_suggestions_all_unknown_patterns(self):
         from check_manifest import check_manifest
